@@ -177,6 +177,14 @@ void AppearanceConfig::sendDemoMessages()
 {
     //add a fake message
     AdiumThemeContentInfo message(AdiumThemeMessageInfo::HistoryRemoteToLocal);
+    message.setMessage(i18n("Ok!"));
+    message.setSenderDisplayName(i18n("larry@example.com"));
+    message.setSenderScreenName(i18n("Larry Demo"));
+    message.setService(i18n("Jabber"));
+    message.setTime(QDateTime::currentDateTime());
+    ui->chatView->addContentMessage(message);
+
+    message = AdiumThemeContentInfo(AdiumThemeMessageInfo::HistoryRemoteToLocal);
     message.setMessage(i18n("Bye Bye"));
     message.setSenderDisplayName(i18n("larry@example.com"));
     message.setSenderScreenName(i18n("Larry Demo"));
@@ -184,6 +192,14 @@ void AppearanceConfig::sendDemoMessages()
     message.setTime(QDateTime::currentDateTime());
     ui->chatView->addContentMessage(message);
 
+    message = AdiumThemeContentInfo(AdiumThemeMessageInfo::HistoryLocalToRemote);
+    message.setMessage(i18n("Have fun!"));
+    message.setSenderDisplayName(i18n("ted@example.com"));
+    message.setSenderScreenName(i18n("Ted Example"));
+    message.setService(i18n("Jabber"));
+    message.setTime(QDateTime::currentDateTime());
+    ui->chatView->addContentMessage(message);
+
     message = AdiumThemeContentInfo(AdiumThemeMessageInfo::HistoryLocalToRemote);
     message.setMessage(i18n("cya"));
     message.setSenderDisplayName(i18n("ted@example.com"));
@@ -192,6 +208,19 @@ void AppearanceConfig::sendDemoMessages()
     message.setTime(QDateTime::currentDateTime());
     ui->chatView->addContentMessage(message);
 
+    AdiumThemeStatusInfo statusMessage;
+    statusMessage.setMessage(i18n("Ted Example waves."));
+    statusMessage.setTime(QDateTime::currentDateTime());
+    statusMessage.setService(i18n("Jabber"));
+    ui->chatView->addStatusMessage(statusMessage);
+
+    statusMessage = AdiumThemeStatusInfo();
+    statusMessage.setMessage(i18n("Ted Example has left the chat.")); //FIXME sync this with chat text logic.
+    statusMessage.setTime(QDateTime::currentDateTime());
+    statusMessage.setService(i18n("Jabber"));
+    statusMessage.setStatus(QLatin1String("away"));
+    ui->chatView->addStatusMessage(statusMessage);
+
     message = AdiumThemeContentInfo(AdiumThemeMessageInfo::RemoteToLocal);
     message.setMessage(i18n("Hello"));
     message.setSenderDisplayName(i18n("larry@example.com"));
@@ -200,6 +229,24 @@ void AppearanceConfig::sendDemoMessages()
     message.setTime(QDateTime::currentDateTime());
     ui->chatView->addContentMessage(message);
 
+    message = AdiumThemeContentInfo(AdiumThemeMessageInfo::RemoteToLocal);
+    message.setMessage(i18n("What's up?"));
+    message.setSenderDisplayName(i18n("larry@example.com"));
+    message.setSenderScreenName(i18n("Larry Demo"));
+    message.setService(i18n("Jabber"));
+    message.setTime(QDateTime::currentDateTime());
+    ui->chatView->addContentMessage(message);
+
+    message = AdiumThemeContentInfo(AdiumThemeMessageInfo::LocalToRemote);
+    message.setMessage(i18n("Check out which cool adium themes work "
+                            "<a href=\"http://community.kde.org/Real-Time_Communication_and_Collaboration/Components/Chat_Window/Themes\">"
+                            "here</a>!"));
+    message.setSenderDisplayName(i18n("ted@example.com"));
+    message.setSenderScreenName(i18n("Ted Example"));
+    message.setService(i18n("Jabber"));
+    message.setTime(QDateTime::currentDateTime());
+    ui->chatView->addContentMessage(message);
+
     message = AdiumThemeContentInfo(AdiumThemeMessageInfo::LocalToRemote);
     message.setMessage(i18n("A different example message"));
     message.setSenderDisplayName(i18n("ted@example.com"));
@@ -208,7 +255,14 @@ void AppearanceConfig::sendDemoMessages()
     message.setTime(QDateTime::currentDateTime());
     ui->chatView->addContentMessage(message);
 
-    AdiumThemeStatusInfo  statusMessage;
+    statusMessage = AdiumThemeStatusInfo();
+    statusMessage.setMessage(i18n("Ted Example is now Away.")); //FIXME sync this with chat text logic.
+    statusMessage.setTime(QDateTime::currentDateTime());
+    statusMessage.setService(i18n("Jabber"));
+    statusMessage.setStatus(QLatin1String("away"));
+    ui->chatView->addStatusMessage(statusMessage);
+
+    statusMessage = AdiumThemeStatusInfo();
     statusMessage.setMessage(i18n("Ted Example has left the chat.")); //FIXME sync this with chat text logic.
     statusMessage.setTime(QDateTime::currentDateTime());
     statusMessage.setService(i18n("Jabber"));
