@@ -86,6 +86,8 @@ ChatWidget::ChatWidget(const Tp::TextChannelPtr & channel, const Tp::AccountPtr
 {
     d->channel = channel;
     d->account = account;
+    d->logManager = new LogManager(this);
+
 
     //load translations for this library. keep this before any i18n() calls in library code
     KGlobal::locale()->insertCatalog(QLatin1String("ktpchat"));
@@ -187,15 +189,15 @@ ChatWidget::ChatWidget(const Tp::TextChannelPtr & channel, const Tp::AccountPtr
     connect(this, SIGNAL(searchTextComplete(bool)), d->ui.searchBar, SLOT(onSearchTextComplete(bool)));
 
     // initialize LogManager
-    d->logManager = new LogManager(account, channel->targetContact(), this);
-    d->logManager->setFetchAmount(3);
-    d->logManager->setTextChannel(channel);
+    if (!d->isGroupChat) {
+        d->logManager->setFetchAmount(3);
+        d->logManager->setTextChannel(d->account, d->channel);
+    }
 }
 
 ChatWidget::~ChatWidget()
 {
     d->channel->requestClose(); // ensure closing; does nothing, if already closed
-    delete d->logManager;
     delete d;
 }
 
@@ -405,9 +407,6 @@ void ChatWidget::onHistoryFetched(const QList<AdiumThemeContentInfo> &messages)
     Q_FOREACH(const Tp::ReceivedMessage &message, d->channel->messageQueue()) {
         handleIncomingMessage(message);
     }
-
-    delete d->logManager;
-    d->logManager = 0;
 }
 
 int ChatWidget::unreadMessageCount() const
@@ -755,7 +754,7 @@ void ChatWidget::onContactPresenceChange(const Tp::ContactPtr & contact, const K
                             presence.statusMessage());
         }
     }
-    
+
     if (!message.isNull()) {
         AdiumThemeStatusInfo statusMessage;
         statusMessage.setMessage(message);
